==> pw-iso20022-SRU2023-9.4.7-sources.jar: com/prowidesoftware/swift/model/mx/dic/CharacterSearch1Choice.java <==

package com.prowidesoftware.swift.model.mx.dic;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Set of characters to be matched to be considered as valid.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CharacterSearch1Choice", propOrder = {
    "eq",
    "neq",
    "ct",
    "nct"
})
public class CharacterSearch1Choice {

    @XmlElement(name = "EQ")
    protected String eq;
    @XmlElement(name = "NEQ")
    protected String neq;
    @XmlElement(name = "CT")
    protected String ct;
    @XmlElement(name = "NCT")
    protected String nct;

    /**
     * Gets the value of the eq property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQ() {
        return eq;
    }

    /**
     * Sets the value of the eq property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public CharacterSearch1Choice setEQ(String value) {
        this.eq = value;
        return this;
    }

    /**
     * Gets the value of the neq property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNEQ() {
        return neq;
    }

    /**
     * Sets the value of the neq property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public CharacterSearch1Choice setNEQ(String value) {
        this.neq = value;
        return this;
    }

    /**
     * Gets the value of the ct property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCT() {
        return ct;
    }

    /**
     * Sets the value of the ct property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public CharacterSearch1Choice setCT(String value) {
        this.ct = value;
        return this;
    }

    /**
     * Gets the value of the nct property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNCT() {
        return nct;
    }

    /**
     * Sets the value of the nct property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public CharacterSearch1Choice setNCT(String value) {
        this.nct = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}

==> pw-iso20022-SRU2024-10.2.4-sources.jar: com/prowidesoftware/swift/model/mx/dic/CharacterSearch1Choice.java <==

package com.prowidesoftware.swift.model.mx.dic;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Set of characters to be matched to be considered as valid.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CharacterSearch1Choice", propOrder = {
    "eq",
    "neq",
    "ct",
    "nct"
})
public class CharacterSearch1Choice {

    @XmlElement(name = "EQ")
    protected String eq;
    @XmlElement(name = "NEQ")
    protected String neq;
    @XmlElement(name = "CT")
    protected String ct;
    @XmlElement(name = "NCT")
    protected String nct;

    /**
     * Gets the value of the eq property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQ() {
        return eq;
    }

    /**
     * Sets the value of the eq property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public CharacterSearch1Choice setEQ(String value) {
        this.eq = value;
        return this;
    }

    /**
     * Gets the value of the neq property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNEQ() {
        return neq;
    }

    /**
     * Sets the value of the neq property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public CharacterSearch1Choice setNEQ(String value) {
        this.neq = value;
        return this;
    }

    /**
     * Gets the value of the ct property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCT() {
        return ct;
    }

    /**
     * Sets the value of the ct property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public CharacterSearch1Choice setCT(String value) {
        this.ct = value;
        return this;
    }

    /**
     * Gets the value of the nct property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNCT() {
        return nct;
    }

    /**
     * Sets the value of the nct property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public CharacterSearch1Choice setNCT(String value) {
        this.nct = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}
